#include "../include/dos.h"

int log_file(char *timestamp)
{
    FILE *fp;                   /* File pointer */
    uint32_t i;                 /* Counter variable */
    struct host *host;
    char mode;                  /* Mode of opened file */

    /* Open logfile */
    if (opt.addlogfile)
        mode = 'a';
    else
        mode = 'w';

    if ((fp = fopen(opt.logfile, &mode)) == NULL) {
        perror(opt.logfile);
        exit(1);
    }
#ifdef DEBUG
    printf("Opened logfile.\n");
#endif

    /* Process hosts tree */
    for (i = 0; i <= max_id; i++) {
		/* Quiet mode */
		if (opt.quiet) {
        	if (hosts[i].pts > opt.critical) {
				if (opt.redir) 
				/* Print redirector */
				switch(opt.rtype) {
					case REDIR_IPFILTER:
						fprintf(fp, "#REDIRECTOR# rdr %s from %s/32 to 0.0.0.0/0 port = 80 -> %s port %d\n", opt.pcap_dev, hosts[i].ipstr, opt.rhost, opt.rport);
						fprintf(fp, "#FIREWALL# pass in quick on %s proto tcp/udp from %s/32 to any port = 53\n", opt.pcap_dev, hosts[i].ipstr);
						fprintf(fp, "#FIREWALL# pass in quick on %s proto tcp/udp from %s/32 to any port = 80\n", opt.pcap_dev, hosts[i].ipstr);
						fprintf(fp, "#FIREWALL# pass in quick on %s proto tcp/udp from %s/32 to %s/32 port = %d\n", opt.pcap_dev, hosts[i].ipstr, opt.rhost, opt.rport);
						fprintf(fp, "#FIREWALL# block in quick on %s from %s/32 to any\n", opt.pcap_dev, hosts[i].ipstr);
				}
				else fprintf(fp, "%s\n", hosts[i].ipstr);
			}

		/* Normal output */
		} else {
        	if (hosts[i].pts > opt.critical)
           	 fprintf(fp, "%sCRITICAL : %s got %d points.\n", timestamp,
           	         hosts[i].ipstr, hosts[i].pts);
        	else if (hosts[i].pts > opt.warning)
           	 fprintf(fp, "%sWarning : %s got %d points.\n", timestamp,
           	         hosts[i].ipstr, hosts[i].pts);
		}
    }

    /* Close logfile */
    fclose(fp);

#ifdef DEBUG
    printf("Closed logfile.\n");
#endif
}
